Coder

Struct Coder 

pub struct Coder<S, C = FeaturedCode> { /* private fields */ }
A coder type that can be used for either encode or decode which determined by De type.

Implementations

Source

impl<S, C> Coder<S, C>
where S: Body, C: Code<S::Data>, S::Data: AsRef<[u8]>,

pub const fn new(body: S, coder: C) -> Self

Construct a new coder.

pub fn into_inner(self) -> S